/*
 * Copyright (C) 2001, John Leuner.
 *
 * This file is part of the kissme project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2,
 * or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*
 * @doc
 * @module disass.h |
 *
 * Prototypes for disassembling functions.
 *
 */

#ifndef __DISASS_H__
#define __DISASS_H__

#include "stdtypes.h"
#include <stdio.h>

int DISASS_PrintInstruction(byte* instr, byte* codestart);
void DISASS_PrintInstructionName(FILE* stream, byte code);

#endif

/* end of disass.h */
